@@ -21,7 +21,7 @@ use Moose;
 use Moose::Util::TypeConstraints;
 use MooseX::StrictConstructor;
 
-our $VERSION = '0.01';
+our $VERSION = '0.04';
 
 use Chart::OFC2;
 use Chart::OFC2::Labels;
@@ -29,15 +29,15 @@ use Chart::OFC2::Labels;
 
 =head1 PROPERTIES
 
-    subtype 'Chart-OFC2-YAxis'
+    subtype 'Chart.OFC2.YAxis'
         => as 'Object'
         => where { $_[0]->isa('Chart::OFC2::YAxis') };
-    subtype 'Chart-OFC2-XAxis' 
+    subtype 'Chart.OFC2.XAxis' 
         => as 'Object'
         => where { $_[0]->isa('Chart::OFC2::XAxis') };
 
     has 'name'        => ( is => 'rw', isa => enum(['x_axis', 'y_axis', 'y_axis_right']), required => 1 );
-    has 'labels'      => ( is => 'rw', isa => 'Chart-OFC2-Labels', coerce  => 1);
+    has 'labels'      => ( is => 'rw', isa => 'Chart.OFC2.Labels', coerce  => 1);
     has 'stroke'      => ( is => 'rw', isa => 'Int', );
     has 'colour'      => ( is => 'rw', isa => 'Str',  );
     has 'offset'      => ( is => 'rw', isa => 'Bool', );
@@ -50,28 +50,28 @@ use Chart::OFC2::Labels;
 
 =cut
 
-subtype 'Chart-OFC2-YAxis'
+subtype 'Chart.OFC2.YAxis'
     => as 'Object'
     => where { $_[0]->isa('Chart::OFC2::YAxis') };
-subtype 'Chart-OFC2-XAxis' 
+subtype 'Chart.OFC2.XAxis' 
     => as 'Object'
     => where { $_[0]->isa('Chart::OFC2::XAxis') };
 
-coerce 'Chart-OFC2-XAxis'
+coerce 'Chart.OFC2.XAxis'
     => from 'HashRef'
     => via { Chart::OFC2::XAxis->new($_) };
-coerce 'Chart-OFC2-YAxis'
+coerce 'Chart.OFC2.YAxis'
     => from 'HashRef'
     => via { Chart::OFC2::YAxis->new($_) };
 
 has 'name'        => ( is => 'rw', isa => enum(['x_axis', 'y_axis', 'y_axis_right']), required => 1 );
-has 'labels'      => ( is => 'rw', isa => 'Chart-OFC2-Labels', coerce  => 1);
+has 'labels'      => ( is => 'rw', isa => 'Chart.OFC2.Labels', coerce  => 1);
 has 'stroke'      => ( is => 'rw', isa => 'Int', );
 has 'colour'      => ( is => 'rw', isa => 'Str',  );
 has 'offset'      => ( is => 'rw', isa => 'Bool', );
 has 'grid_colour' => ( is => 'rw', isa => 'Str', );
 has '3d'          => ( is => 'rw', isa => 'Bool', );
-has 'steps'       => ( is => 'rw', isa => 'Chart-OFC2-NaturalInt', );
+has 'steps'       => ( is => 'rw', isa => 'Chart.OFC2.NaturalInt', );
 has 'visible'     => ( is => 'rw', isa => 'Bool',  );
 has 'min'         => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
 has 'max'         => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
@@ -90,7 +90,7 @@ sub TO_JSON {
     return {
         map  { my $v = $self->$_; (defined $v ? ($_ => $v) : ()) }
         grep { $_ ne 'name' }
-        map  { $_->name } $self->meta->compute_all_applicable_attributes
+        map  { $_->name } $self->meta->get_all_attributes
     };
 }
 
