@@ -51,6 +51,6 @@ use Chart::OFC2::HBarValues;
 =cut
 
 has '+type_name' => (default => 'hbar');
-has 'values'     => (is => 'rw', isa => 'Chart-OFC2-HBarValues', 'coerce' => 1,);
+has 'values'     => (is => 'rw', isa => 'Chart.OFC2.HBarValues', 'coerce' => 1,);
 
 1;
