@@ -29,12 +29,12 @@ use Moose;
 use Moose::Util::TypeConstraints;
 use MooseX::StrictConstructor;
 
-our $VERSION = '0.01';
+our $VERSION = '0.04';
 
-subtype 'Chart-OFC2-ToolTip'
+subtype 'Chart.OFC2.ToolTip'
     => as 'Object'
     => where { $_[0]->isa('Chart::OFC2::ToolTip') };
-coerce 'Chart-OFC2-ToolTip'
+coerce 'Chart.OFC2.ToolTip'
     => from 'HashRef'
     => via { Chart::OFC2::ToolTip->new($_) };
 
@@ -76,7 +76,7 @@ sub TO_JSON {
     return {
         map  { my $v = $self->$_; (defined $v ? ($_ => $v) : ()) }
         map  { $_->name }
-        $self->meta->compute_all_applicable_attributes
+        $self->meta->get_all_attributes
     };
 }
 
